@@ -11,7 +11,7 @@
 #'   \item false   -> "logical",       e.g., false -> "logical"
 #'   \item null    -> "null",          e.g., null -> "null"
 #'   \item array   -> [<type>]         e.g., [1, 2] -> ["number"]
-#'   \item object  -> {"name": <type>} e.g., {"age": 32} -> {"age": "number"}
+#'   \item object  -> \{"name": <type>\} e.g., \{"age": 32\} -> \{"age": "number"\}
 #' }
 #'
 #' For more complex JSON objects, ties are broken by taking the most
@@ -68,7 +68,7 @@ json_schema <- function(.x, type = c("string", "value")) {
   .x <- .x %>% json_types
   json <- json_get(.x)
 
-  schema <- list_along(json)
+  schema <- rep_along(list(), json)
 
   is_array <- .x$type == "array"
   is_object <- .x$type == "object"
